#
# spec file for package golang-packaging
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define version_unconverted 14.9.2

Name:           golang-packaging
Version:        14.9.2
Release:        8.3
Summary:        A toolchain to help packaging golang
License:        GPL-3.0
Group:          Development/Languages/Golang
Url:            https://github.com/marguerite/%{name}
Source:         %{name}-%{version}.tar.xz
BuildRequires:  rpm
BuildRequires:  ruby
BuildRequires:  xz
Requires:       go
Requires:       ruby
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
# on openSUSE Leap 42.1, go 1.4.2 owned /etc/rpm/macros.go
Conflicts:      go = 1.4.2

%description
A toolchain to help packaging golang, written in ruby.

%prep
%setup -q
GOARCH=`ruby ./golang-macros.rb --arch`
sed -i "s/GOARCH/$GOARCH/" macros.go

%build

%install
mkdir -p %{buildroot}%{_sysconfdir}/rpm/
mkdir -p %{buildroot}%{_prefix}/lib/rpm/
%if 0%{?suse_version} >= 1320
mkdir -p %{buildroot}%{_prefix}/lib/rpm/fileattrs
install -m0644 golang.attr %{buildroot}%{_prefix}/lib/rpm/fileattrs/
%endif
install -m0755 golang.prov %{buildroot}%{_prefix}/lib/rpm/
install -m0755 golang.req %{buildroot}%{_prefix}/lib/rpm/
cp -r golang %{buildroot}%{_prefix}/lib/rpm/
install -m0755 golang-macros.rb %{buildroot}%{_prefix}/lib/rpm/
install -m0644 macros.go %{buildroot}%{_sysconfdir}/rpm/

%files
%defattr(-,root,root)
%doc COPYING README.md ChangeLog
%config %{_sysconfdir}/rpm/macros.go
%if %{?suse_version} >= 1320
%{_prefix}/lib/rpm/fileattrs/golang.attr
%endif
%{_prefix}/lib/rpm/golang
%{_prefix}/lib/rpm/golang.prov
%{_prefix}/lib/rpm/golang.req
%{_prefix}/lib/rpm/golang-macros.rb

%changelog
* Sun Aug 14 2016 astieger@suse.com
- on openSUSE Leap 42.1, go 1.4.2 owned /etc/rpm/macros.go. Add
  conflict to prevent file conflict on installation without updated
  go packages
* Fri Jul  8 2016 i@marguerite.su
- can't be noarch. we detected %%%%go_arch at build time. it has to be
  architecture-dependent, or it'll be published randomly with one
  from i586/x86_64, whose content (/etc/rpm/macros.go) is unique.
* Tue Jun 21 2016 tboerger@suse.com
- Update to version 14.9.2:
  + [SLE11]some commands need time to finish, immediate close will get wrong status, so use timeout 30s
  + [SLE]ditch named group in regexp in golang.req, the oniguruma in ruby 1.8.7 doesn't support named group
  + fix a typo in cli.rb
  + increate timeout to 300s or go install can't finish
  + Remove runtime dependency for Go API
  + simplify rpmsysinfo.rb
  + release 14.9.1
  + Added go_nostrip macro
* Wed Jun  8 2016 i@marguerite.su
- Update to version 14.9.1:
  * simplify rpmsysinfo.rb: don't guess variables'
    values can be passed in by RPM environment
    variables. use RbConfig to get libdir.
  * support s390x architecture
* Sun Apr 17 2016 mpluskal@suse.com
- Update service
  * use xz for compression
  * change from disabled to localonly
- Update spec file to actually use tarball generated by _service
- Drop useless _servicedata
* Fri Apr 15 2016 tboerger@suse.com
- Switched to service based package updates
- Update to version 14.9.0:
  * do not hardcode go version
  * fix encoding problem in rpmsysinfo.rb
  * [SLE11]some commands need time to finish, immediate close will get wrong status, so use timeout 30s
  * [SLE]ditch named group in regexp in golang.req, the oniguruma in ruby 1.8.7 doesn't support named group
  * fix a typo in cli.rb
  * increate timeout to 300s or go install can't finish
  * Remove runtime dependency for Go API
* Tue Apr  5 2016 i@marguerite.su
- update version 14.8.1
  * bugfix release
  * fix a typo in cli.rb
  * increate timeout to 300s, or go install can't
    finish itself sometimes
* Sun Apr  3 2016 i@marguerite.su
- update version 14.8
  * rpmsysinfo.rb: fix encoding problem in open()
  * cli.rb: ruby 1.8.7 doesn't support passing environment
    variables in popen(), some commands/tests need time to
    finish, an immediate io.close() will get us wrong
    exitstatus (broken pipe, code 13). so use 'timeout'
    module with a 30s and process.wait for them to quit
    successfully.
  * golang.req: the oniguruma in ruby 1.8.7 doesn't support
    named group in regexp. so ditch the named group used in
    go_get_version()
* Wed Feb 24 2016 i@marguerite.su
- update version 14.7
  * do not hardcode go version
* Fri Feb 12 2016 i@marguerite.su
- update version 14.6
  * Fix rbarch for Power architectures
* Fri Jan 22 2016 i@marguerite.su
- update version 14.5
  * fix a typo that prevent golang.req from running (fix #10)
* Fri Jan 22 2016 i@marguerite.su
- update version 14.4
  * fix #5 on golang.req
* Tue Jan 19 2016 i@marguerite.su
- update version 14.3
  * fix: command not found error for go test on SLE
  * fix #5 again: gsub importpath itself is not enough
* Mon Jan 11 2016 i@marguerite.su
- update version 14.2
  * golang.req: fix ' // indirect' comment in import
* Mon Jan 11 2016 i@marguerite.su
- update version 14.1
  * golang.prov fix: uniq! returns nil if everything is unique
* Tue Jan  5 2016 i@marguerite.su
- update version 14
  * if importpath has "test/example", it should survive (github#5)
  * merge macros.go from openSUSE's go here
  * add golang-macros.rb, replacement for the complicated
    macros in shell in macros.go
  * golang-macros.rb:
    + support build with fake build id
    + support build with custom tags (github#7)
    + support pass any -<arg>="a b c" or -<arg>=<value>
    to go install, shared build is possible now
    (not fully support, other macros need to be adapted)
    + --filelist, to generate filelist used in %%files
    section with excluding support
    + use IO.popen to break the build at the exact place
    it fails (github#6)
* Mon Jan  4 2016 i@marguerite.su
- update version 13
  * provides the importpath itself
  * fix regex not to check files like .golden in -source
  * filter "test/example" from Provides
  * split common stuff to a module golang/rpmsysinfo.rb
  * rewrite golang.req, now read from stdin RPM feeds,
    and check __.PKGDEF from .a files for "import"s. (github#3, github#4)
* Sun Jan  3 2016 i@marguerite.su
- update version 12
  * don't find provides/requires on -source, -debuginfo, -debugsource
    subpackages
  * add scripts to generate file lists.
* Sat Jan  2 2016 i@marguerite.su
- update version 11
  * fix for sles and openSUSE < 13.2
* Fri Sep  4 2015 i@marguerite.su
- update version 10
  * support all archtectures like ppc/arm
* Fri Aug 28 2015 i@marguerite.su
- update version 9
  * update golang(API) to 1.5
* Sun Aug  2 2015 i@marguerite.su
- update version 8
  * skip the last "/" in golang.prov, thanks to matwey
* Fri Jul 31 2015 i@marguerite.su
- udpate version 7
  * handle gopkg.in/* requirements
* Fri Jul 24 2015 i@marguerite.su
- update version 6
  * fix golang.req to not treat a sentence as importpath
  * fix golang.attr to correctly detect /usr/bin/*
* Wed Jul 22 2015 i@marguerite.su
- update version 5
  * if a sub-directory doesn't contain any *.go file, do not
    treat it as a Provides candidate.
  * add /usr/bin to golang.attr for go executes to be handled
    by golang-packaging
* Sun Jul 12 2015 i@marguerite.su
- update version 4
  * fix encoding error in golang-strip-builddep
  * add macros.go-extra, extra golang macros for packaging
* Sat Jul 11 2015 i@marguerite.su
- update version 3
  * skip *example*.go/*test*.go for Requires finding
  * support alias format (import xx "xxx") for importpath
  * add golang-strip-builddep, a tool to strip unneeded importpath
    from source codes
* Fri Jul 10 2015 i@marguerite.su
- update version 2
  * fix pkgname detection
* Sun Jul  5 2015 i@marguerite.su
- initial version 1
  * implemented provides
  * implemented requires
